@@ -49,7 +49,7 @@ except ImportError:
     pass
 
 try:
-    import mlflow
+    from mlflow_extend import mlflow
 except ImportError:
     mlflow = None
 
